lmi-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[lmi-commits] [lmi] master 0024cd3 4/4: Force correct permissions for cy


From: Greg Chicares
Subject: [lmi-commits] [lmi] master 0024cd3 4/4: Force correct permissions for cygwin (msw) only
Date: Thu, 7 Dec 2017 12:58:47 -0500 (EST)

branch: master
commit 0024cd3cccfad2da15db0e9f7b1fd7ae36fc2c31
Author: Gregory W. Chicares <address@hidden>
Commit: Gregory W. Chicares <address@hidden>

    Force correct permissions for cygwin (msw) only
---
 check_git_setup.sh | 9 ++++++++-
 1 file changed, 8 insertions(+), 1 deletion(-)

diff --git a/check_git_setup.sh b/check_git_setup.sh
index ba67ad4..fc98d5c 100755
--- a/check_git_setup.sh
+++ b/check_git_setup.sh
@@ -30,12 +30,19 @@ printf "'%s' is current directory\n" $PWD
 printf "'%s' is git toplevel directory\n" $toplevel
 [ "$PWD" = "$toplevel" ] || { printf "fail: PWD is not toplevel\n"; exit 1; }
 
 # For msw (cygwin) only, make sure 'core.filemode' is "false". See:
 #   https://lists.nongnu.org/archive/html/lmi/2017-11/msg00018.html
 
 case $(uname -s) in
   (CYGWIN*)
     printf "cygwin detected\n"
+    printf "forcing correct permissions "
+      for d in . gwc; do (\
+           printf "$d..." \
+        && find ./$d -maxdepth 1 -type f -not -name '*.sh' -not -name '*.sed' 
| xargs chmod -x \
+      )done; \
+    printf "all permissions forced\n"
     git config core.filemode false
     ;;
   (*)
@@ -30,12 +30,19 @@ printf "'%s' is current directory\n" $PWD
 [ "$PWD" = "$toplevel" ] || { printf "fail: PWD is not toplevel\n"; exit 1; }
 
-# For msw (cygwin) only, make sure 'core.filemode' is "false". See:
+# For msw (cygwin) only, force correct permissions, and make sure
+#'core.filemode' is "false". See:
 #   https://lists.nongnu.org/archive/html/lmi/2017-11/msg00018.html
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]